==> hyperstream-0.2.6.tar.gz: hyperstream-0.2.6/hyperstream/tools/stream_broadcaster/2016-11-10_v0.0.1.py <==
# The MIT License (MIT)
# Copyright (c) 2014-2017 University of Bristol
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
# 
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
# DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
# OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE
# OR OTHER DEALINGS IN THE SOFTWARE.

from hyperstream.tool import MultiOutputTool
from hyperstream.stream import StreamInstance, StreamMetaInstance
from hyperstream.time_interval import TimeInterval, MIN_DATE


class StreamBroadcaster(MultiOutputTool):
    def __init__(self, func, output_plate_values):
        super(StreamBroadcaster, self).__init__(func=func, output_plate_values=output_plate_values)

    def _execute(self, source, splitting_stream, interval, output_plate):
        if splitting_stream is not None:
            raise NotImplementedError("Splitting stream not supported for this tool")

        # TODO: This factor does use the time interval, but only applies a function on the stream.
        # Will need to change this in future instances
        time_interval = TimeInterval(MIN_DATE, interval.end)
        data = self.func(source.window(time_interval, force_calculation=True))

        if data is None:
            return

        if isinstance(data, StreamInstance):
            data = [data]

        for doc in data:
            for vv in self.output_plate_values:
                yield StreamMetaInstance(doc, (output_plate.meta_data_id, str(vv)))

==> hyperstream-0.3.2.tar.gz: hyperstream-0.3.2/hyperstream/tools/stream_broadcaster/2016-11-10_v0.0.1.py <==
# The MIT License (MIT)
# Copyright (c) 2014-2017 University of Bristol
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
# 
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
# DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
# OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE
# OR OTHER DEALINGS IN THE SOFTWARE.

from hyperstream.tool import MultiOutputTool
from hyperstream.stream import StreamInstance, StreamMetaInstance

from copy import deepcopy


class StreamBroadcaster(MultiOutputTool):
    def __init__(self, func):
        super(StreamBroadcaster, self).__init__(func=func)

    def _execute(self, source, splitting_stream, interval, meta_data_id, output_plate_values):
        if splitting_stream is not None:
            raise ValueError("Splitting stream not supported for this tool")

        for doc in source.window(interval, force_calculation=True):
            for vv in output_plate_values:
                data = self.func(deepcopy(doc.value))
                yield StreamMetaInstance(StreamInstance(doc.timestamp, data), vv)
